#include "SimStepStudiesProcessor.h"


#include <IMPL/LCCollectionVec.h>
#include "EVENT/CalorimeterHit.h"
#include "EVENT/MCParticle.h"


// ----- include for verbosity dependend logging ---------
#include "marlin/VerbosityLevels.h"

SimStepStudiesProcessor aSimStepStudiesProcessor;

SimStepStudiesProcessor::SimStepStudiesProcessor() : Processor("SimStepStudiesProcessor")
{
  _description = "SimStepStudiesProcessor : Perform some studies (TO UPDATE) based on output of SimHitStepsToCaloHitProcessor";

  StringVec colDefault = {"G4StepAsHit"};
  registerInputCollections( LCIO::CALORIMETERHIT,
			    "InputG4StepAsCaloHitsCollections" , 
			    "Name of the input collections containing G4Step stored as Calorimeter Hits"  ,
			    m_colNames ,
			    colDefault ) ;
  /*
  registerOutputCollection( LCIO::CALORIMETERHIT,
			    "OutputCollection" , 
			    "Name of the output collections"  ,
			    m_outputColName ,
			    std::string("G4StepAsHit" ) ) ;
  
  registerOptionalParameter("ActivateILDmode", 
			    "Activate ILD CellID decoding, ony option supported now",
			    m_CellID_ILDStyle,
                            true);
  */
}

void SimStepStudiesProcessor::init()
{
  printParameters();
}

void SimStepStudiesProcessor::processEvent( LCEvent * evt )
{
  if ( not isFirstEvent() ) return;
  for (std::string& colName : m_colNames)
    {
      LCCollection* col = NULL;
      try
	{
	  col = evt->getCollection( colName );
	}
      catch( lcio::DataNotAvailableException &e )
	{
	  streamlog_out(WARNING) << colName << " collection not available" << std::endl;
	  col = NULL;
	}
      if (not col) continue;
      for (int i=0; i<col->getNumberOfElements(); ++i)
	{
	  CalorimeterHit* hit=dynamic_cast<CalorimeterHit*> ( col->getElementAt(i) );
	  if (not hit) continue;
	  std::cout << "Yo : ";
	  MCParticle* mcp=dynamic_cast<MCParticle*>( hit->getRawHit() );
	  if (not mcp)
	    std::cout << " :-( ";
	  else
	    {
	      std::cout << mcp->getPDG() << "  (" << mcp->getCharge() <<")  : " << mcp->id();
	    }
	  std::cout << " // [ " << hit->getCellID1() << "]" << std::endl;
	}
    }
}
